@@ -138,11 +138,11 @@ namespace lsp
                   [count] "+r" (count)
                 : [HALF] "r" (&msmatrix_const[0])
                 : "cc", "memory",
-                  "q0", "q1", "q2", "q3",
-                  "q4", "q5", "q6", "q7",
-                  "q16", "q17", "q18", "q19",
-                  "q20", "q21", "q22", "q23",
-                  "q24", "q25"
+                  "v0", "v1", "v2", "v3",
+                  "v4", "v5", "v6", "v7",
+                  "v16", "v17", "v18", "v19",
+                  "v20", "v21", "v22", "v23",
+                  "v24", "v25"
             );
         }
 
@@ -230,10 +230,10 @@ namespace lsp
                   [count] "+r" (count)
                 : [HALF] "r" (&msmatrix_const[0])
                 : "cc", "memory",
-                  "q0", "q1", "q2", "q3",
-                  "q4", "q5", "q6", "q7",
-                  "q16", "q17", "q18", "q19",
-                  "q20", "q21", "q22", "q23"
+                  "v0", "v1", "v2", "v3",
+                  "v4", "v5", "v6", "v7",
+                  "v16", "v17", "v18", "v19",
+                  "v20", "v21", "v22", "v23"
             );
         }
 
@@ -315,10 +315,10 @@ namespace lsp
                   [count] "+r" (count)
                 : [HALF] "r" (&msmatrix_const[0])
                 : "cc", "memory",
-                  "q0", "q1", "q2", "q3",
-                  "q4", "q5", "q6", "q7",
-                  "q16", "q17", "q18", "q19",
-                  "q24", "q25"
+                  "v0", "v1", "v2", "v3",
+                  "v4", "v5", "v6", "v7",
+                  "v16", "v17", "v18", "v19",
+                  "v24", "v25"
             );
         }
 
@@ -330,10 +330,10 @@ namespace lsp
                   [count] "+r" (count)
                 : [HALF] "r" (&msmatrix_const[0])
                 : "cc", "memory",
-                  "q0", "q1", "q2", "q3",
-                  "q4", "q5", "q6", "q7",
-                  "q16", "q17", "q18", "q19",
-                  "q24", "q25"
+                  "v0", "v1", "v2", "v3",
+                  "v4", "v5", "v6", "v7",
+                  "v16", "v17", "v18", "v19",
+                  "v24", "v25"
             );
         }
 
@@ -408,9 +408,9 @@ namespace lsp
                   [count] "+r" (count)
                 :
                 : "cc", "memory",
-                  "q0", "q1", "q2", "q3",
-                  "q4", "q5", "q6", "q7",
-                  "q16", "q17", "q18", "q19"
+                  "v0", "v1", "v2", "v3",
+                  "v4", "v5", "v6", "v7",
+                  "v16", "v17", "v18", "v19"
             );
         }
 
@@ -422,9 +422,9 @@ namespace lsp
                   [count] "+r" (count)
                 :
                 : "cc", "memory",
-                  "q0", "q1", "q2", "q3",
-                  "q4", "q5", "q6", "q7",
-                  "q16", "q17", "q18", "q19"
+                  "v0", "v1", "v2", "v3",
+                  "v4", "v5", "v6", "v7",
+                  "v16", "v17", "v18", "v19"
             );
         }
 
