@@ -117,7 +117,7 @@ namespace lsp
                   [count] "+r" (count)
                 :
                 : "cc", "memory",
-                  "q0", "q1", "q2", "q3" , "q4", "q5", "q6", "q7"
+                  "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7"
             );
         }
 
@@ -213,7 +213,7 @@ namespace lsp
                   [count] "+r" (count)
                 :
                 : "cc", "memory",
-                  "q0", "q1", "q2", "q3" , "q4", "q5", "q6", "q7"
+                  "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7"
             );
         }
 
@@ -331,8 +331,8 @@ namespace lsp
                  [count] "+r" (count)
                :
                : "cc", "memory",
-                 "q0", "q1", "q2", "q3", "q4", "q5", "q6", "q7",
-                 "q16", "q17", "q18", "q19", "q20", "q21", "q22", "q23"
+                 "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                 "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23"
            );
        }
 
@@ -345,8 +345,8 @@ namespace lsp
                  [count] "+r" (count)
                :
                : "cc", "memory",
-                 "q0", "q1", "q2", "q3", "q4", "q5", "q6", "q7",
-                 "q16", "q17", "q18", "q19", "q20", "q21", "q22", "q23"
+                 "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                 "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23"
            );
        }
 
@@ -359,8 +359,8 @@ namespace lsp
                  [count] "+r" (count)
                :
                : "cc", "memory",
-                 "q0", "q1", "q2", "q3", "q4", "q5", "q6", "q7",
-                 "q16", "q17", "q18", "q19", "q20", "q21", "q22", "q23"
+                 "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                 "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23"
            );
        }
 
@@ -373,8 +373,8 @@ namespace lsp
                  [count] "+r" (count)
                :
                : "cc", "memory",
-                 "q0", "q1", "q2", "q3", "q4", "q5", "q6", "q7",
-                 "q16", "q17", "q18", "q19", "q20", "q21", "q22", "q23"
+                 "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                 "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23"
            );
        }
 
@@ -494,9 +494,9 @@ namespace lsp
                  [count] "+r" (count)
                :
                : "cc", "memory",
-                 "q0", "q1", "q2", "q3" , "q4", "q5", "q6", "q7",
-                 "q16", "q17", "q18", "q19",
-                 "q24", "q25", "q26", "q27"
+                 "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                 "v16", "v17", "v18", "v19",
+                 "v24", "v25", "v26", "v27"
            );
        }
 
@@ -509,9 +509,9 @@ namespace lsp
                  [count] "+r" (count)
                :
                : "cc", "memory",
-                 "q0", "q1", "q2", "q3" , "q4", "q5", "q6", "q7",
-                 "q16", "q17", "q18", "q19",
-                 "q24", "q25", "q26", "q27"
+                 "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                 "v16", "v17", "v18", "v19",
+                 "v24", "v25", "v26", "v27"
            );
        }
 
@@ -631,8 +631,8 @@ namespace lsp
                    [count] "+r" (count)
                  :
                  : "cc", "memory",
-                   "q0", "q1", "q2", "q3", "q4", "q5", "q6", "q7",
-                   "q16", "q17", "q18", "q19", "q20", "q21", "q22", "q23"
+                   "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                   "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23"
              );
          }
 
@@ -645,8 +645,8 @@ namespace lsp
                    [count] "+r" (count)
                  :
                  : "cc", "memory",
-                   "q0", "q1", "q2", "q3", "q4", "q5", "q6", "q7",
-                   "q16", "q17", "q18", "q19", "q20", "q21", "q22", "q23"
+                   "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                   "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23"
              );
          }
 
@@ -659,8 +659,8 @@ namespace lsp
                    [count] "+r" (count)
                  :
                  : "cc", "memory",
-                   "q0", "q1", "q2", "q3", "q4", "q5", "q6", "q7",
-                   "q16", "q17", "q18", "q19", "q20", "q21", "q22", "q23"
+                   "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                   "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23"
              );
          }
 
@@ -673,8 +673,8 @@ namespace lsp
                    [count] "+r" (count)
                  :
                  : "cc", "memory",
-                   "q0", "q1", "q2", "q3", "q4", "q5", "q6", "q7",
-                   "q16", "q17", "q18", "q19", "q20", "q21", "q22", "q23"
+                   "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                   "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23"
              );
          }
 
@@ -798,9 +798,9 @@ namespace lsp
                   [count] "+r" (count)
                 :
                 : "cc", "memory",
-                  "q0", "q1", "q2", "q3" , "q4", "q5", "q6", "q7",
-                  "q16", "q17", "q18", "q19",
-                  "q24", "q25", "q26", "q27"
+                  "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                  "v16", "v17", "v18", "v19",
+                  "v24", "v25", "v26", "v27"
             );
         }
 
@@ -813,9 +813,9 @@ namespace lsp
                   [count] "+r" (count)
                 :
                 : "cc", "memory",
-                  "q0", "q1", "q2", "q3" , "q4", "q5", "q6", "q7",
-                  "q16", "q17", "q18", "q19",
-                  "q24", "q25", "q26", "q27"
+                  "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                  "v16", "v17", "v18", "v19",
+                  "v24", "v25", "v26", "v27"
             );
         }
 
