@@ -35,7 +35,7 @@ namespace lsp
             ARCH_ARM_ASM
             (
                 // x8 blocks
-                __ASM_EMIT("subs        %[count], $8")
+                __ASM_EMIT("subs        %[count], #8")
                 __ASM_EMIT("blo         2f")
                 __ASM_EMIT("1:")
                 __ASM_EMIT("vldm        %[src_re], {q0-q1}")            // q0, q1 = sr
@@ -44,23 +44,23 @@ namespace lsp
                 __ASM_EMIT("vldm        %[dst_im], {q6-q7}")            // q6, q7 = di
                 __ASM_EMIT("vmul.f32    q8, q0, q4")                    // q8 = sr*dr
                 __ASM_EMIT("vmul.f32    q9, q1, q5")
-                __ASM_EMIT("add         %[src_re], $0x20")
+                __ASM_EMIT("add         %[src_re], #0x20")
                 __ASM_EMIT("vmul.f32    q4, q2, q4")                    // q4 = si*dr
                 __ASM_EMIT("vmul.f32    q5, q3, q5")
-                __ASM_EMIT("add         %[src_im], $0x20")
+                __ASM_EMIT("add         %[src_im], #0x20")
                 __ASM_EMIT("vmls.f32    q8, q2, q6")                    // q8 = sr*dr - si*di
                 __ASM_EMIT("vmls.f32    q9, q3, q7")
                 __ASM_EMIT("vmla.f32    q4, q0, q6")                    // q5 = si*dr + sr*di
                 __ASM_EMIT("vmla.f32    q5, q1, q7")
                 __ASM_EMIT("vstm        %[dst_re], {q8-q9}")
                 __ASM_EMIT("vstm        %[dst_im], {q4-q5}")
-                __ASM_EMIT("subs        %[count], $8")
-                __ASM_EMIT("add         %[dst_re], $0x20")
-                __ASM_EMIT("add         %[dst_im], $0x20")
+                __ASM_EMIT("subs        %[count], #8")
+                __ASM_EMIT("add         %[dst_re], #0x20")
+                __ASM_EMIT("add         %[dst_im], #0x20")
                 __ASM_EMIT("bhs         1b")
                 __ASM_EMIT("2:")
                 // x4 blocks
-                __ASM_EMIT("adds        %[count], $4")
+                __ASM_EMIT("adds        %[count], #4")
                 __ASM_EMIT("blt         4f")
                 __ASM_EMIT("vldm        %[src_re], {q0}")               // q0  = sr
                 __ASM_EMIT("vldm        %[src_im], {q2}")               // q2  = si
@@ -68,18 +68,18 @@ namespace lsp
                 __ASM_EMIT("vldm        %[dst_im], {q6}")               // q6  = di
                 __ASM_EMIT("vmul.f32    q8, q0, q4")                    // q8  = sr*dr
                 __ASM_EMIT("vmul.f32    q4, q2, q4")                    // q4  = si*dr
-                __ASM_EMIT("add         %[src_re], $0x10")
+                __ASM_EMIT("add         %[src_re], #0x10")
                 __ASM_EMIT("vmls.f32    q8, q2, q6")                    // q8  = sr*dr - si*di
                 __ASM_EMIT("vmla.f32    q4, q0, q6")                    // q4  = si*dr + sr*di
-                __ASM_EMIT("add         %[src_im], $0x10")
+                __ASM_EMIT("add         %[src_im], #0x10")
                 __ASM_EMIT("vstm        %[dst_re], {q8}")
                 __ASM_EMIT("vstm        %[dst_im], {q4}")
-                __ASM_EMIT("sub         %[count], $4")
-                __ASM_EMIT("add         %[dst_re], $0x10")
-                __ASM_EMIT("add         %[dst_im], $0x10")
+                __ASM_EMIT("sub         %[count], #4")
+                __ASM_EMIT("add         %[dst_re], #0x10")
+                __ASM_EMIT("add         %[dst_im], #0x10")
                 __ASM_EMIT("4:")
                 // x1 blocks
-                __ASM_EMIT("adds        %[count], $3")
+                __ASM_EMIT("adds        %[count], #3")
                 __ASM_EMIT("blt         6f")
                 __ASM_EMIT("5:")
                 __ASM_EMIT("vld1.32     {d0[], d1[]}, [%[src_re]]")     // q0  = sr
@@ -88,15 +88,15 @@ namespace lsp
                 __ASM_EMIT("vld1.32     {d12[], d13[]}, [%[dst_im]]")   // q6  = di
                 __ASM_EMIT("vmul.f32    q8, q0, q4")                    // q8  = sr*dr
                 __ASM_EMIT("vmul.f32    q4, q2, q4")                    // q4  = si*dr
-                __ASM_EMIT("add         %[src_re], $0x04")
+                __ASM_EMIT("add         %[src_re], #0x04")
                 __ASM_EMIT("vmls.f32    q8, q2, q6")                    // q8  = sr*dr - si*di
                 __ASM_EMIT("vmla.f32    q4, q0, q6")                    // q4  = si*dr + sr*di
-                __ASM_EMIT("add         %[src_im], $0x04")
+                __ASM_EMIT("add         %[src_im], #0x04")
                 __ASM_EMIT("vst1.32     {d16[0]}, [%[dst_re]]")
                 __ASM_EMIT("vst1.32     {d8[0]}, [%[dst_im]]")
-                __ASM_EMIT("subs        %[count], $1")
-                __ASM_EMIT("add         %[dst_re], $0x04")
-                __ASM_EMIT("add         %[dst_im], $0x04")
+                __ASM_EMIT("subs        %[count], #1")
+                __ASM_EMIT("add         %[dst_re], #0x04")
+                __ASM_EMIT("add         %[dst_im], #0x04")
                 __ASM_EMIT("bge         5b")
                 __ASM_EMIT("6:")
 
@@ -115,7 +115,7 @@ namespace lsp
             ARCH_ARM_ASM
             (
                 // x8 blocks
-                __ASM_EMIT("subs        %[count], $8")
+                __ASM_EMIT("subs        %[count], #8")
                 __ASM_EMIT("blo         2f")
                 __ASM_EMIT("1:")
                 __ASM_EMIT("vldm        %[src1_re], {q0-q1}")           // q0, q1 = sr
@@ -123,47 +123,47 @@ namespace lsp
                 __ASM_EMIT("vldm        %[src2_re], {q4-q5}")           // q4, q5 = dr
                 __ASM_EMIT("vldm        %[src2_im], {q6-q7}")           // q6, q7 = di
                 __ASM_EMIT("vmul.f32    q8, q0, q4")                    // q8 = sr*dr
-                __ASM_EMIT("add         %[src1_re], $0x20")
+                __ASM_EMIT("add         %[src1_re], #0x20")
                 __ASM_EMIT("vmul.f32    q9, q1, q5")
-                __ASM_EMIT("add         %[src1_im], $0x20")
+                __ASM_EMIT("add         %[src1_im], #0x20")
                 __ASM_EMIT("vmul.f32    q4, q2, q4")                    // q4 = si*dr
                 __ASM_EMIT("vmul.f32    q5, q3, q5")
                 __ASM_EMIT("vmls.f32    q8, q2, q6")                    // q8 = sr*dr - si*di
-                __ASM_EMIT("add         %[src2_re], $0x20")
+                __ASM_EMIT("add         %[src2_re], #0x20")
                 __ASM_EMIT("vmls.f32    q9, q3, q7")
                 __ASM_EMIT("vmla.f32    q4, q0, q6")                    // q5 = si*dr + sr*di
-                __ASM_EMIT("add         %[src2_im], $0x20")
+                __ASM_EMIT("add         %[src2_im], #0x20")
                 __ASM_EMIT("vmla.f32    q5, q1, q7")
                 __ASM_EMIT("vstm        %[dst_re], {q8-q9}")
                 __ASM_EMIT("vstm        %[dst_im], {q4-q5}")
-                __ASM_EMIT("subs        %[count], $8")
-                __ASM_EMIT("add         %[dst_re], $0x20")
-                __ASM_EMIT("add         %[dst_im], $0x20")
+                __ASM_EMIT("subs        %[count], #8")
+                __ASM_EMIT("add         %[dst_re], #0x20")
+                __ASM_EMIT("add         %[dst_im], #0x20")
                 __ASM_EMIT("bhs         1b")
                 __ASM_EMIT("2:")
                 // x4 blocks
-                __ASM_EMIT("adds        %[count], $4")
+                __ASM_EMIT("adds        %[count], #4")
                 __ASM_EMIT("blt         4f")
                 __ASM_EMIT("vldm        %[src1_re], {q0}")              // q0  = sr
                 __ASM_EMIT("vldm        %[src1_im], {q2}")              // q2  = si
                 __ASM_EMIT("vldm        %[src2_re], {q4}")              // q4  = dr
                 __ASM_EMIT("vldm        %[src2_im], {q6}")              // q6  = di
                 __ASM_EMIT("vmul.f32    q8, q0, q4")                    // q8  = sr*dr
-                __ASM_EMIT("add         %[src1_re], $0x10")
+                __ASM_EMIT("add         %[src1_re], #0x10")
                 __ASM_EMIT("vmul.f32    q4, q2, q4")                    // q4  = si*dr
-                __ASM_EMIT("add         %[src1_im], $0x10")
+                __ASM_EMIT("add         %[src1_im], #0x10")
                 __ASM_EMIT("vmls.f32    q8, q2, q6")                    // q8  = sr*dr - si*di
-                __ASM_EMIT("add         %[src2_re], $0x10")
+                __ASM_EMIT("add         %[src2_re], #0x10")
                 __ASM_EMIT("vmla.f32    q4, q0, q6")                    // q4  = si*dr + sr*di
-                __ASM_EMIT("add         %[src2_im], $0x10")
+                __ASM_EMIT("add         %[src2_im], #0x10")
                 __ASM_EMIT("vstm        %[dst_re], {q8}")
                 __ASM_EMIT("vstm        %[dst_im], {q4}")
-                __ASM_EMIT("sub         %[count], $4")
-                __ASM_EMIT("add         %[dst_re], $0x10")
-                __ASM_EMIT("add         %[dst_im], $0x10")
+                __ASM_EMIT("sub         %[count], #4")
+                __ASM_EMIT("add         %[dst_re], #0x10")
+                __ASM_EMIT("add         %[dst_im], #0x10")
                 __ASM_EMIT("4:")
                 // x1 blocks
-                __ASM_EMIT("adds        %[count], $3")
+                __ASM_EMIT("adds        %[count], #3")
                 __ASM_EMIT("blt         6f")
                 __ASM_EMIT("5:")
                 __ASM_EMIT("vld1.32     {d0[], d1[]}, [%[src1_re]]")    // q0  = sr
@@ -171,18 +171,18 @@ namespace lsp
                 __ASM_EMIT("vld1.32     {d8[], d9[]}, [%[src2_re]]")    // q4  = dr
                 __ASM_EMIT("vld1.32     {d12[], d13[]}, [%[src2_im]]")  // q6  = di
                 __ASM_EMIT("vmul.f32    q8, q0, q4")                    // q8  = sr*dr
-                __ASM_EMIT("add         %[src1_re], $0x04")
+                __ASM_EMIT("add         %[src1_re], #0x04")
                 __ASM_EMIT("vmul.f32    q4, q2, q4")                    // q4  = si*dr
-                __ASM_EMIT("add         %[src1_im], $0x04")
+                __ASM_EMIT("add         %[src1_im], #0x04")
                 __ASM_EMIT("vmls.f32    q8, q2, q6")                    // q8  = sr*dr - si*di
-                __ASM_EMIT("add         %[src2_re], $0x04")
+                __ASM_EMIT("add         %[src2_re], #0x04")
                 __ASM_EMIT("vmla.f32    q4, q0, q6")                    // q4  = si*dr + sr*di
-                __ASM_EMIT("add         %[src2_im], $0x04")
+                __ASM_EMIT("add         %[src2_im], #0x04")
                 __ASM_EMIT("vst1.32     {d16[0]}, [%[dst_re]]")
                 __ASM_EMIT("vst1.32     {d8[0]}, [%[dst_im]]")
-                __ASM_EMIT("subs        %[count], $1")
-                __ASM_EMIT("add         %[dst_re], $0x04")
-                __ASM_EMIT("add         %[dst_im], $0x04")
+                __ASM_EMIT("subs        %[count], #1")
+                __ASM_EMIT("add         %[dst_re], #0x04")
+                __ASM_EMIT("add         %[dst_im], #0x04")
                 __ASM_EMIT("bge         5b")
                 __ASM_EMIT("6:")
 
@@ -201,7 +201,7 @@ namespace lsp
         {
             ARCH_ARM_ASM
             (
-                __ASM_EMIT("subs            %[count], $8")
+                __ASM_EMIT("subs            %[count], #8")
                 __ASM_EMIT("blo             2f")
 
                 // x8 blocks
@@ -242,12 +242,12 @@ namespace lsp
                 __ASM_EMIT("vmul.f32        q3, q3, q5")
                 __ASM_EMIT("vst1.32         {q0-q1}, [%[dst_re]]!")
                 __ASM_EMIT("vst1.32         {q2-q3}, [%[dst_im]]!")
-                __ASM_EMIT("subs            %[count], $8")
+                __ASM_EMIT("subs            %[count], #8")
                 __ASM_EMIT("bhs             1b")
 
                 // x4 blocks
                 __ASM_EMIT("2:")
-                __ASM_EMIT("adds            %[count], $4")
+                __ASM_EMIT("adds            %[count], #4")
                 __ASM_EMIT("blt             4f")
                 __ASM_EMIT("vld1.32         {q4}, [%[src_re]]!")            // q4  = sr
                 __ASM_EMIT("vld1.32         {q6}, [%[src_im]]!")            // q6  = si
@@ -271,11 +271,11 @@ namespace lsp
                 __ASM_EMIT("vmul.f32        q2, q2, q4")
                 __ASM_EMIT("vst1.32         {q0}, [%[dst_re]]!")
                 __ASM_EMIT("vst1.32         {q2}, [%[dst_im]]!")
-                __ASM_EMIT("sub             %[count], $4")
+                __ASM_EMIT("sub             %[count], #4")
 
                 // x1 blocks
                 __ASM_EMIT("4:")
-                __ASM_EMIT("adds            %[count], $3")
+                __ASM_EMIT("adds            %[count], #3")
                 __ASM_EMIT("blt             6f")
                 __ASM_EMIT("5:")
                 __ASM_EMIT("vldm.32         %[src_re]!, {s4}")              // s4  = sr
@@ -292,7 +292,7 @@ namespace lsp
                 __ASM_EMIT("vdiv.f32        s2, s2, s4")                    // s2  = (sr*dr + si*di) / R
                 __ASM_EMIT("vstm.32         %[dst_re]!, {s0}")
                 __ASM_EMIT("vstm.32         %[dst_im]!, {s2}")
-                __ASM_EMIT("subs            %[count], $1")
+                __ASM_EMIT("subs            %[count], #1")
                 __ASM_EMIT("bge             5b")
 
                 __ASM_EMIT("6:")
@@ -311,7 +311,7 @@ namespace lsp
         {
             ARCH_ARM_ASM
             (
-                __ASM_EMIT("subs            %[count], $8")
+                __ASM_EMIT("subs            %[count], #8")
                 __ASM_EMIT("blo             2f")
 
                 // x8 blocks
@@ -352,12 +352,12 @@ namespace lsp
                 __ASM_EMIT("vmul.f32        q3, q3, q5")
                 __ASM_EMIT("vst1.32         {q0-q1}, [%[dst_re]]!")
                 __ASM_EMIT("vst1.32         {q2-q3}, [%[dst_im]]!")
-                __ASM_EMIT("subs            %[count], $8")
+                __ASM_EMIT("subs            %[count], #8")
                 __ASM_EMIT("bhs             1b")
 
                 // x4 blocks
                 __ASM_EMIT("2:")
-                __ASM_EMIT("adds            %[count], $4")
+                __ASM_EMIT("adds            %[count], #4")
                 __ASM_EMIT("blt             4f")
                 __ASM_EMIT("vld1.32         {q4}, [%[src_re]]!")            // q4  = sr
                 __ASM_EMIT("vld1.32         {q6}, [%[src_im]]!")            // q6  = si
@@ -381,11 +381,11 @@ namespace lsp
                 __ASM_EMIT("vmul.f32        q2, q2, q4")
                 __ASM_EMIT("vst1.32         {q0}, [%[dst_re]]!")
                 __ASM_EMIT("vst1.32         {q2}, [%[dst_im]]!")
-                __ASM_EMIT("sub             %[count], $4")
+                __ASM_EMIT("sub             %[count], #4")
 
                 // x1 blocks
                 __ASM_EMIT("4:")
-                __ASM_EMIT("adds            %[count], $3")
+                __ASM_EMIT("adds            %[count], #3")
                 __ASM_EMIT("blt             6f")
                 __ASM_EMIT("5:")
                 __ASM_EMIT("vldm.32         %[src_re]!, {s4}")              // s4  = sr
@@ -402,7 +402,7 @@ namespace lsp
                 __ASM_EMIT("vdiv.f32        s2, s2, s4")                    // s2  = (sr*dr + si*di) / R
                 __ASM_EMIT("vstm.32         %[dst_re]!, {s0}")
                 __ASM_EMIT("vstm.32         %[dst_im]!, {s2}")
-                __ASM_EMIT("subs            %[count], $1")
+                __ASM_EMIT("subs            %[count], #1")
                 __ASM_EMIT("bge             5b")
 
                 __ASM_EMIT("6:")
@@ -421,7 +421,7 @@ namespace lsp
         {
             ARCH_ARM_ASM
             (
-                __ASM_EMIT("subs            %[count], $8")
+                __ASM_EMIT("subs            %[count], #8")
                 __ASM_EMIT("blo             2f")
 
                 // x8 blocks
@@ -462,12 +462,12 @@ namespace lsp
                 __ASM_EMIT("vmul.f32        q3, q3, q5")
                 __ASM_EMIT("vst1.32         {q0-q1}, [%[dst_re]]!")
                 __ASM_EMIT("vst1.32         {q2-q3}, [%[dst_im]]!")
-                __ASM_EMIT("subs            %[count], $8")
+                __ASM_EMIT("subs            %[count], #8")
                 __ASM_EMIT("bhs             1b")
 
                 // x4 blocks
                 __ASM_EMIT("2:")
-                __ASM_EMIT("adds            %[count], $4")
+                __ASM_EMIT("adds            %[count], #4")
                 __ASM_EMIT("blt             4f")
                 __ASM_EMIT("vld1.32         {q4}, [%[t_re]]!")              // q4  = sr
                 __ASM_EMIT("vld1.32         {q6}, [%[t_im]]!")              // q6  = si
@@ -491,11 +491,11 @@ namespace lsp
                 __ASM_EMIT("vmul.f32        q2, q2, q4")
                 __ASM_EMIT("vst1.32         {q0}, [%[dst_re]]!")
                 __ASM_EMIT("vst1.32         {q2}, [%[dst_im]]!")
-                __ASM_EMIT("sub             %[count], $4")
+                __ASM_EMIT("sub             %[count], #4")
 
                 // x1 blocks
                 __ASM_EMIT("4:")
-                __ASM_EMIT("adds            %[count], $3")
+                __ASM_EMIT("adds            %[count], #3")
                 __ASM_EMIT("blt             6f")
                 __ASM_EMIT("5:")
                 __ASM_EMIT("vldm.32         %[t_re]!, {s4}")                // s4  = sr
@@ -512,7 +512,7 @@ namespace lsp
                 __ASM_EMIT("vdiv.f32        s2, s2, s4")                    // s2  = (sr*dr + si*di) / R
                 __ASM_EMIT("vstm.32         %[dst_re]!, {s0}")
                 __ASM_EMIT("vstm.32         %[dst_im]!, {s2}")
-                __ASM_EMIT("subs            %[count], $1")
+                __ASM_EMIT("subs            %[count], #1")
                 __ASM_EMIT("bge             5b")
 
                 __ASM_EMIT("6:")
@@ -532,7 +532,7 @@ namespace lsp
         {
             ARCH_ARM_ASM
             (
-                __ASM_EMIT("subs            %[count], $16")
+                __ASM_EMIT("subs            %[count], #16")
                 __ASM_EMIT("blo             2f")
 
                 //-----------------------------------------------------------------
@@ -586,14 +586,14 @@ namespace lsp
                 __ASM_EMIT("vmul.f32        q2, q2, q10")
                 __ASM_EMIT("vmul.f32        q3, q3, q13")
                 __ASM_EMIT("vst1.32         {q0-q1}, [%[dst]]!")
-                __ASM_EMIT("subs            %[count], $16")
+                __ASM_EMIT("subs            %[count], #16")
                 __ASM_EMIT("vst1.32         {q2-q3}, [%[dst]]!")
                 __ASM_EMIT("bhs             1b")
 
                 //-----------------------------------------------------------------
                 // x8 blocks
                 __ASM_EMIT("2:")
-                __ASM_EMIT("adds            %[count], $8")
+                __ASM_EMIT("adds            %[count], #8")
                 __ASM_EMIT("blt             4f")
                 __ASM_EMIT("vld1.32         {q0-q1}, [%[src_re]]!")     // q0 = r1, q1 = r2
                 __ASM_EMIT("vld1.32         {q4-q5}, [%[src_im]]!")     // q4 = i1, q5 = i2
@@ -620,13 +620,13 @@ namespace lsp
                 // Complete comuting
                 __ASM_EMIT("vmul.f32        q0, q0, q4")                // q0 = R / sqrt(R) = sqrt(R)
                 __ASM_EMIT("vmul.f32        q1, q1, q7")
-                __ASM_EMIT("sub             %[count], $8")
+                __ASM_EMIT("sub             %[count], #8")
                 __ASM_EMIT("vst1.32         {q0-q1}, [%[dst]]!")
 
                 //-----------------------------------------------------------------
                 // x4 blocks
                 __ASM_EMIT("4:")
-                __ASM_EMIT("adds            %[count], $4")
+                __ASM_EMIT("adds            %[count], #4")
                 __ASM_EMIT("blt             6f")
                 __ASM_EMIT("vld1.32         {q0}, [%[src_re]]!")        // q0 = r
                 __ASM_EMIT("vld1.32         {q2}, [%[src_im]]!")        // q2 = i
@@ -642,12 +642,12 @@ namespace lsp
                 __ASM_EMIT("vmul.f32        q1, q1, q3")                // q1 = 1/sqrt(R) = x2 = x1 * (3 - R * x1 * x1) / 2
                 // Complete comuting
                 __ASM_EMIT("vmul.f32        q0, q0, q1")                // q0 = R / sqrt(R) = sqrt(R)
-                __ASM_EMIT("sub             %[count], $4")
+                __ASM_EMIT("sub             %[count], #4")
                 __ASM_EMIT("vst1.32         {q0}, [%[dst]]!")
 
                 // x1 blocks
                 __ASM_EMIT("6:")
-                __ASM_EMIT("adds        %[count], $3")
+                __ASM_EMIT("adds        %[count], #3")
                 __ASM_EMIT("blt         8f")
                 __ASM_EMIT("7:")
                 __ASM_EMIT("vldm.32     %[src_re]!, {s0}")              // s0 = r
@@ -655,7 +655,7 @@ namespace lsp
                 __ASM_EMIT("vmul.f32    s0, s0, s0")                    // s0 = r*r
                 __ASM_EMIT("vmla.f32    s0, s1, s1")                    // s0 = r*r + i*i
                 __ASM_EMIT("vsqrt.f32   s0, s0")                        // s0 = sqrt(r*r + i*i)
-                __ASM_EMIT("subs        %[count], $1")
+                __ASM_EMIT("subs        %[count], #1")
                 __ASM_EMIT("vstm.32     %[dst]!, {s0}")
                 __ASM_EMIT("bge         7b")
 
@@ -674,7 +674,7 @@ namespace lsp
         {
             ARCH_ARM_ASM
             (
-                __ASM_EMIT("subs            %[count], $8")
+                __ASM_EMIT("subs            %[count], #8")
                 __ASM_EMIT("blo             2f")
 
                 //-----------------------------------------------------------------
@@ -705,7 +705,7 @@ namespace lsp
                 __ASM_EMIT("vmul.f32        q2, q2, q4")                // q2 = -i / R
                 __ASM_EMIT("vmul.f32        q3, q3, q5")
 
-                __ASM_EMIT("subs            %[count], $8")
+                __ASM_EMIT("subs            %[count], #8")
                 __ASM_EMIT("vst1.32         {q0-q1}, [%[dst_re]]!")
                 __ASM_EMIT("vst1.32         {q2-q3}, [%[dst_im]]!")
                 __ASM_EMIT("bhs             1b")
@@ -713,7 +713,7 @@ namespace lsp
                 //-----------------------------------------------------------------
                 // x4 blocks
                 __ASM_EMIT("2:")
-                __ASM_EMIT("adds            %[count], $4")
+                __ASM_EMIT("adds            %[count], #4")
                 __ASM_EMIT("blt             4f")
                 __ASM_EMIT("vld1.32         {q0}, [%[dst_re]]")         // q0 = r
                 __ASM_EMIT("vld1.32         {q2}, [%[dst_im]]")         // q2 = i
@@ -729,13 +729,13 @@ namespace lsp
                 __ASM_EMIT("vneg.f32        q2, q2")                    // q2 = -i
                 __ASM_EMIT("vmul.f32        q0, q0, q4")                // q0 = r / R
                 __ASM_EMIT("vmul.f32        q2, q2, q4")                // q2 = -i / R
-                __ASM_EMIT("sub             %[count], $4")
+                __ASM_EMIT("sub             %[count], #4")
                 __ASM_EMIT("vst1.32         {q0}, [%[dst_re]]!")
                 __ASM_EMIT("vst1.32         {q2}, [%[dst_im]]!")
 
                 // x1 blocks
                 __ASM_EMIT("4:")
-                __ASM_EMIT("adds            %[count], $3")
+                __ASM_EMIT("adds            %[count], #3")
                 __ASM_EMIT("blt             6f")
                 __ASM_EMIT("5:")
                 __ASM_EMIT("vldm.32         %[dst_re], {s0}")           // s0 = r
@@ -745,7 +745,7 @@ namespace lsp
                 __ASM_EMIT("vneg.f32        s2, s2")                    // s2 = -i
                 __ASM_EMIT("vdiv.f32        s0, s0, s4")                // s0 = r / R
                 __ASM_EMIT("vdiv.f32        s2, s2, s4")                // s2 = -i / R
-                __ASM_EMIT("subs            %[count], $1")
+                __ASM_EMIT("subs            %[count], #1")
                 __ASM_EMIT("vstm.32         %[dst_re]!, {s0}")
                 __ASM_EMIT("vstm.32         %[dst_im]!, {s2}")
                 __ASM_EMIT("bge             5b")
@@ -765,7 +765,7 @@ namespace lsp
         {
             ARCH_ARM_ASM
             (
-                __ASM_EMIT("subs            %[count], $8")
+                __ASM_EMIT("subs            %[count], #8")
                 __ASM_EMIT("blo             2f")
 
                 //-----------------------------------------------------------------
@@ -796,7 +796,7 @@ namespace lsp
                 __ASM_EMIT("vmul.f32        q2, q2, q4")                // q2 = -i / R
                 __ASM_EMIT("vmul.f32        q3, q3, q5")
 
-                __ASM_EMIT("subs            %[count], $8")
+                __ASM_EMIT("subs            %[count], #8")
                 __ASM_EMIT("vst1.32         {q0-q1}, [%[dst_re]]!")
                 __ASM_EMIT("vst1.32         {q2-q3}, [%[dst_im]]!")
                 __ASM_EMIT("bhs             1b")
@@ -804,7 +804,7 @@ namespace lsp
                 //-----------------------------------------------------------------
                 // x4 blocks
                 __ASM_EMIT("2:")
-                __ASM_EMIT("adds            %[count], $4")
+                __ASM_EMIT("adds            %[count], #4")
                 __ASM_EMIT("blt             4f")
                 __ASM_EMIT("vld1.32         {q0}, [%[src_re]]!")        // q0 = r
                 __ASM_EMIT("vld1.32         {q2}, [%[src_im]]!")        // q2 = i
@@ -820,13 +820,13 @@ namespace lsp
                 __ASM_EMIT("vneg.f32        q2, q2")                    // q2 = -i
                 __ASM_EMIT("vmul.f32        q0, q0, q4")                // q0 = r / R
                 __ASM_EMIT("vmul.f32        q2, q2, q4")                // q2 = -i / R
-                __ASM_EMIT("sub             %[count], $4")
+                __ASM_EMIT("sub             %[count], #4")
                 __ASM_EMIT("vst1.32         {q0}, [%[dst_re]]!")
                 __ASM_EMIT("vst1.32         {q2}, [%[dst_im]]!")
 
                 // x1 blocks
                 __ASM_EMIT("4:")
-                __ASM_EMIT("adds            %[count], $3")
+                __ASM_EMIT("adds            %[count], #3")
                 __ASM_EMIT("blt             6f")
                 __ASM_EMIT("5:")
                 __ASM_EMIT("vldm.32         %[src_re]!, {s0}")          // s0 = r
@@ -836,7 +836,7 @@ namespace lsp
                 __ASM_EMIT("vneg.f32        s2, s2")                    // s2 = -i
                 __ASM_EMIT("vdiv.f32        s0, s0, s4")                // s0 = r / R
                 __ASM_EMIT("vdiv.f32        s2, s2, s4")                // s2 = -i / R
-                __ASM_EMIT("subs            %[count], $1")
+                __ASM_EMIT("subs            %[count], #1")
                 __ASM_EMIT("vstm.32         %[dst_re]!, {s0}")
                 __ASM_EMIT("vstm.32         %[dst_im]!, {s2}")
                 __ASM_EMIT("bge             5b")
