@@ -44,7 +44,7 @@ namespace lsp
             (
                 __ASM_EMIT("mov         %[a], %[tmp]")
                 __ASM_EMIT("mov         %[b], %[tmp]")
-                __ASM_EMIT("subs        %[n], %[items], $8")
+                __ASM_EMIT("subs        %[n], %[items], #8")
                 __ASM_EMIT("blo         2f")
 
                 __ASM_EMIT("1:")
@@ -62,7 +62,7 @@ namespace lsp
                 // q1 = r5' r7' i5' i7'
                 __ASM_EMIT("vtrn.32     q4, q5")                // q4 = r0' r4' i0' i4', q5 = r2' r6' i2' i6'
                 __ASM_EMIT("vtrn.32     q0, q1")                // q0 = r1' r5' i1' i5', q1 = r3' r7' i3' i7'
-                __ASM_EMIT("vext.32     q6, q1, q1, $2")        // q6 = i3' i7' r3' r7'
+                __ASM_EMIT("vext.32     q6, q1, q1, #2")        // q6 = i3' i7' r3' r7'
 
                 __ASM_EMIT("vsub.f32    q2, q0, q6")            // q2 = r1'-i3' r5'-i7' i1'-r3' i5'-r7' = r1" r5" i3" i7"
                 __ASM_EMIT("vsub.f32    q1, q4, q5")            // q1 = r0'-r2' r4'-r6' i0'-i2' i4'-i6' = r2" r6" i2" i6"
@@ -80,10 +80,10 @@ namespace lsp
 
                 __ASM_EMIT("vrev64.32   q1, q1")                // q1 = i3" i0" i1" i2"
                 __ASM_EMIT("vrev64.32   q3, q3")                // q3 = i7" i4" i5" i6"
-                __ASM_EMIT("vext.32     q1, q1, q1, $1")        // q1 = i0" i1" i2" i3"
-                __ASM_EMIT("vext.32     q3, q3, q3, $1")        // q3 = i4" i5" i6" i7"
+                __ASM_EMIT("vext.32     q1, q1, q1, #1")        // q1 = i0" i1" i2" i3"
+                __ASM_EMIT("vext.32     q3, q3, q3, #1")        // q3 = i4" i5" i6" i7"
 
-                __ASM_EMIT("subs        %[n], $8")              // n   -= 8
+                __ASM_EMIT("subs        %[n], #8")              // n   -= 8
                 __ASM_EMIT("vstm        %[b]!, {q0-q3}")
                 __ASM_EMIT("bhs         1b")
                 __ASM_EMIT("2:")
@@ -104,7 +104,7 @@ namespace lsp
                 ARCH_ARM_ASM
                 (
                     __ASM_EMIT("mov         %[a], %[tmp]")
-                    __ASM_EMIT("subs        %[k], %[items], $16")
+                    __ASM_EMIT("subs        %[k], %[items], #16")
                     __ASM_EMIT("vldm        %[XFFT_A]!, {q8-q11}")   // q8   = wr1, q9 = wr2, q10 = wi1, q11 = wi2
                     __ASM_EMIT("blo         2f")
                     // 8x butterflies
@@ -130,11 +130,11 @@ namespace lsp
                     __ASM_EMIT("vadd.f32    q4, q4, q13")       // q4   = ar2 + cr2
                     __ASM_EMIT("vadd.f32    q5, q5, q15")       // q5   = ai2 + ci2
                     __ASM_EMIT("vstm        %[a]!, {q0-q7}")
-                    __ASM_EMIT("subs        %[k], $16")
+                    __ASM_EMIT("subs        %[k], #16")
                     __ASM_EMIT("bge         1b")
 
                     __ASM_EMIT("2:")
-                    __ASM_EMIT("adds        %[k], $8")
+                    __ASM_EMIT("adds        %[k], #8")
                     __ASM_EMIT("blo         4f")
                     // 4x butterflies
                     __ASM_EMIT("vldm        %[a], {q0-q3}")     // q0   = ar1, q1 = ai1, q2 = br1, q3 = bi1
@@ -173,7 +173,7 @@ namespace lsp
                         // Initialize sub-loop
                         __ASM_EMIT("mov         %[p], %[n]")
                         __ASM_EMIT("vldm        %[XFFT_A], {q8-q11}")           // q8   = wr1, q9 = wr2, q10 = wi1, q11 = wi2
-                        __ASM_EMIT("add         %[b], %[a], %[n], LSL $2")      // b    = &a[n*4]
+                        __ASM_EMIT("add         %[b], %[a], %[n], LSL #2")      // b    = &a[n*4]
                         // 8x butterflies
                         __ASM_EMIT("3:")
                         // Calc cr and ci
@@ -197,7 +197,7 @@ namespace lsp
                         __ASM_EMIT("vadd.f32    q2, q2, q13")                   // q2   = ar2 + cr2
                         __ASM_EMIT("vadd.f32    q3, q3, q15")                   // q3   = ai2 + ci2
                         __ASM_EMIT("vstm        %[b]!, {q4-q7}")
-                        __ASM_EMIT("subs        %[p], $16")
+                        __ASM_EMIT("subs        %[p], #16")
                         __ASM_EMIT("vstm        %[a]!, {q0-q3}")
                         __ASM_EMIT("beq         4f")
                         // Prepare next loop: rotate angle
@@ -239,9 +239,9 @@ namespace lsp
 
             ARCH_ARM_ASM(
                 // Initialize sub-loop
-                __ASM_EMIT("add         %[b], %[a], %[n], LSL $2")      // b    = &a[n*4]
+                __ASM_EMIT("add         %[b], %[a], %[n], LSL #2")      // b    = &a[n*4]
                 __ASM_EMIT("vld1.32     {d30[], d31[]}, [%[fftk]]")     // q15  = 1 / items
-                __ASM_EMIT("add         %[db], %[da], %[n], LSL $1")    // db   = &da[n*2]
+                __ASM_EMIT("add         %[db], %[da], %[n], LSL #1")    // db   = &da[n*2]
                 __ASM_EMIT("vldm        %[XFFT_A], {q8-q11}")           // q8   = wr1, q9 = wr2, q10 = wi1, q11 = wi2
                 __ASM_EMIT("vmov        q14, q15")                      // q14  = 1 / items
                 // 8x butterflies
@@ -262,7 +262,7 @@ namespace lsp
                 __ASM_EMIT("vmul.f32    q5, q15")                       // q5   = (ar2 + cr2) / items
                 __ASM_EMIT("vmul.f32    q6, q14")                       // q6   = (ar1 - cr1) / items
                 __ASM_EMIT("vmul.f32    q7, q15")                       // q7   = (ar2 - cr2) / items
-                __ASM_EMIT("subs        %[items], $16")
+                __ASM_EMIT("subs        %[items], #16")
                 __ASM_EMIT("vstm        %[db]!, {q6-q7}")
                 __ASM_EMIT("vstm        %[da]!, {q4-q5}")
                 __ASM_EMIT("beq         2f")
