@@ -403,8 +403,7 @@ namespace lsp
 
                 : [dst] "+r" (dst), [src] "+r" (src),
                   [mask] "=&r"(mask), [f] "+r" (f),
-                  __IF_32([count] "+g" (count))
-                  __IF_64([count] "+r" (count))
+                  [count] X86_PGREG (count)
                 : [d] "r" (d),
                   [X_MASK] "m" (dyn_biquad_x4_mask),
                   [MASK] "m" (MASK)
@@ -528,8 +527,7 @@ namespace lsp
 
                 : [dst] "+r" (dst), [src] "+r" (src),
                   [mask] "=&r"(mask), [f] "+r" (f),
-                  __IF_32([count] "+g" (count))
-                  __IF_64([count] "+r" (count))
+                  [count] X86_PGREG (count)
                 : [d] "r" (d),
                   [X_MASK] "m" (dyn_biquad_x4_mask),
                   [MASK] "m" (MASK)
@@ -821,8 +819,7 @@ namespace lsp
 
                 : [dst] "+r" (dst), [src] "+r" (src), [f] "+r" (f),
                   [mask] "=&r"(mask),
-                  __IF_32([count] "+g" (count))
-                  __IF_64([count] "+r" (count))
+                  [count] X86_PGREG (count)
                 : [d] "r" (d),
                   [X_MASK] "m" (dyn_biquad_x8_mask)
                 : "cc", "memory",
@@ -830,7 +827,7 @@ namespace lsp
                   "%xmm4", "%xmm5", "%xmm6", "%xmm7"
             );
         }
-    }
-}
+    } /* namespace avx */
+} /* namespace lsp */
 
 #endif /* PRIVATE_DSP_ARCH_X86_AVX_FILTERS_DYNAMIC_H_ */
