@@ -50,6 +50,13 @@ namespace lsp
         }
     )
 
+    IF_ARCH_AARCH64(
+        namespace asimd
+        {
+            void hsla_to_rgba(float *dst, const float *src, size_t count);
+        }
+    )
+
     typedef void (* hsla_to_rgba_t)(float *dst, const float *src, size_t count);
 }
 
@@ -89,6 +96,7 @@ PTEST_BEGIN("dsp.graphics", hsla_to_rgba, 5, 5000)
             call("generic::hsla_to_rgba", dst, src, count, scale, generic::hsla_to_rgba);
             IF_ARCH_X86(call("sse2::hsla_to_rgba", dst, src, count, scale, sse2::hsla_to_rgba));
             IF_ARCH_ARM(call("neon_d32::hsla_to_rgba", dst, src, count, scale, neon_d32::hsla_to_rgba));
+            IF_ARCH_AARCH64(call("asimd::hsla_to_rgba", dst, src, count, scale, asimd::hsla_to_rgba));
 
             PTEST_SEPARATOR;
         }
