@@ -49,6 +49,13 @@ namespace lsp
         }
     )
 
+    IF_ARCH_AARCH64(
+        namespace asimd
+        {
+            void rgba_to_hsla(float *dst, const float *src, size_t count);
+        }
+    )
+
     typedef void (* rgba_to_hsla_t)(float *dst, const float *src, size_t count);
 }
 
@@ -87,6 +94,7 @@ PTEST_BEGIN("dsp.graphics", rgba_to_hsla, 5, 5000)
             call("generic::rgba_to_hsla", dst, src, count, generic::rgba_to_hsla);
             IF_ARCH_X86(call("sse2::rgba_to_hsla", dst, src, count, sse2::rgba_to_hsla));
             IF_ARCH_ARM(call("neon_d32::rgba_to_hsla", dst, src, count, neon_d32::rgba_to_hsla));
+            IF_ARCH_AARCH64(call("asimd::rgba_to_hsla", dst, src, count, asimd::rgba_to_hsla));
 
             PTEST_SEPARATOR;
         }
