@@ -88,9 +88,12 @@ namespace lsp
                 ui::IPort          *pMeshPort;
                 ui::IPort          *pPathPort;
                 tk::FileDialog     *pDialog;
+                ctl::Widget        *pFilePreview;
                 tk::Menu           *pMenu;
                 DataSink           *pDataSink;
                 DragInSink         *pDragInSink;
+                bool                bFullSample;
+                bool                bLoadPreview;
                 lltl::parray<file_format_t>     vFormats;
                 lltl::parray<tk::MenuItem>      vMenuItems;
                 lltl::pphash<char, ui::IPort>   vClipboardBind;
@@ -98,6 +101,9 @@ namespace lsp
                 ctl::Integer        sWaveBorder;
                 ctl::Integer        sFadeInBorder;
                 ctl::Integer        sFadeOutBorder;
+                ctl::Integer        sStretchBorder;
+                ctl::Integer        sLoopBorder;
+                ctl::Integer        sPlayBorder;
                 ctl::Integer        sLineWidth;
                 ctl::LCString       sMainText;
                 ctl::Integer        sLabelRadius;
@@ -114,7 +120,15 @@ namespace lsp
                 ctl::Expression     sTailCut;
                 ctl::Expression     sFadeIn;
                 ctl::Expression     sFadeOut;
+                ctl::Expression     sStretch;
+                ctl::Expression     sStretchBegin;
+                ctl::Expression     sStretchEnd;
+                ctl::Expression     sLoop;
+                ctl::Expression     sLoopBegin;
+                ctl::Expression     sLoopEnd;
+                ctl::Expression     sPlayPosition;
                 ctl::Expression     sLength;
+                ctl::Expression     sActualLength;
 
                 ctl::Padding        sIPadding;
 
@@ -123,11 +137,17 @@ namespace lsp
                 ctl::Color          sGlassColor;
                 ctl::Color          sLineColor;
                 ctl::Color          sMainColor;
+                ctl::Color          sStretchColor;
+                ctl::Color          sStretchBorderColor;
+                ctl::Color          sLoopColor;
+                ctl::Color          sLoopBorderColor;
+                ctl::Color          sPlayColor;
                 ctl::Color          sLabelTextColor[tk::AudioSample::LABELS];
                 ctl::Color          sLabelBgColor;
 
             protected:
                 static status_t     slot_audio_sample_submit(tk::Widget *sender, void *ptr, void *data);
+                static status_t     slot_dialog_change(tk::Widget *sender, void *ptr, void *data);
                 static status_t     slot_dialog_submit(tk::Widget *sender, void *ptr, void *data);
                 static status_t     slot_dialog_hide(tk::Widget *sender, void *ptr, void *data);
                 static status_t     slot_popup_cut_action(tk::Widget *sender, void *ptr, void *data);
@@ -139,24 +159,27 @@ namespace lsp
             protected:
                 void                show_file_dialog();
                 void                update_path();
+                void                preview_file();
                 void                commit_file();
                 void                sync_status();
                 void                sync_labels();
+                void                sync_markers();
                 void                sync_mesh();
                 tk::Menu           *create_menu();
                 tk::MenuItem       *create_menu_item(tk::Menu *menu);
 
             public:
                 explicit AudioSample(ui::IWrapper *wrapper, tk::AudioSample *widget);
-                virtual ~AudioSample();
+                virtual ~AudioSample() override;
 
-                virtual status_t    init();
+                virtual status_t    init() override;
+                virtual void        destroy() override;
 
             public:
-                virtual void        set(ui::UIContext *ctx, const char *name, const char *value);
-                virtual void        end(ui::UIContext *ctx);
-                virtual void        notify(ui::IPort *port);
-                virtual void        reloaded(const tk::StyleSheet *sheet);
+                virtual void        set(ui::UIContext *ctx, const char *name, const char *value) override;
+                virtual void        end(ui::UIContext *ctx) override;
+                virtual void        notify(ui::IPort *port) override;
+                virtual void        reloaded(const tk::StyleSheet *sheet) override;
         };
 
     } /* namespace ctl */
