@@ -45,6 +45,7 @@
 // Non-official features
 #include <lsp-plug.in/3rdparty/ardour/inline-display.h>
 #include <lsp-plug.in/plug-fw/wrap/lv2/ext/osc.h>
+#include <lsp-plug.in/stdlib/string.h>
 
 // Some definitions that may be lacking in older LV2 headers
 #ifndef LV2_ATOM__Object
@@ -59,4 +60,18 @@
     #define LV2_UI__scaleFactor         LV2_UI_PREFIX "scaleFactor"
 #endif /* LV2_UI__scaleFactor */
 
+namespace lsp
+{
+    inline void lv2_set_string(char *dst, size_t limit, const char *src, size_t len)
+    {
+        if ((src != NULL) && (len > 0))
+        {
+            size_t copy     = (len >= limit) ? limit-1 : len;
+            ::memcpy(dst, src, len);
+            dst[copy]       = '\0';
+        }
+        else
+            dst[0]          = '\0';
+    }
+} /* namespace lsp */
 #endif /* LSP_PLUG_IN_PLUG_FW_WRAP_LV2_LV2_H_ */
