@@ -308,6 +308,9 @@ namespace lsp
 
         void Fader::submit_value()
         {
+            if (pPort == NULL)
+                return;
+
             tk::Fader *fdr = tk::widget_cast<tk::Fader>(wWidget);
             if (fdr == NULL)
                 return;
@@ -375,8 +378,11 @@ namespace lsp
             }
 
             fdr->value()->set(value);
-            pPort->set_value(dfl);
-            pPort->notify_all();
+            if (pPort != NULL)
+            {
+                pPort->set_value(dfl);
+                pPort->notify_all();
+            }
         }
 
         void Fader::commit_value(float value)
