@@ -253,7 +253,7 @@ namespace lsp
                     expr::Parameters params;
                     LSPString text, funit;
 
-                    meta::format_value(buf, TMP_BUF_SIZE, mdata, fValue, nPrecision);
+                    meta::format_value(buf, TMP_BUF_SIZE, mdata, fValue, nPrecision, false);
                     text.set_ascii(buf);
                     sunit.format(&funit);
                     if (mdata->unit == meta::U_BOOL)
@@ -312,7 +312,7 @@ namespace lsp
                 return false;
 
             float fv;
-            status_t res = parse_value(&fv, value->get_utf8(), meta);
+            status_t res = parse_value(&fv, value->get_utf8(), meta, false);
             if (res != STATUS_OK)
                 return false;
 
@@ -415,7 +415,7 @@ namespace lsp
 
             // Set-up value
             char buf[TMP_BUF_SIZE];
-            format_value(buf, TMP_BUF_SIZE, mdata, _this->fValue, _this->nPrecision);
+            format_value(buf, TMP_BUF_SIZE, mdata, _this->fValue, _this->nPrecision, false);
             popup->sValue.text()->set_raw(buf);
             popup->sValue.selection()->set_all();
 
@@ -492,7 +492,7 @@ namespace lsp
             if (popup->sValue.text()->format(&value) == STATUS_OK)
             {
                 float v;
-                if (meta::parse_value(&v, value.get_utf8(), meta) == STATUS_OK)
+                if (meta::parse_value(&v, value.get_utf8(), meta, false) == STATUS_OK)
                 {
                     style = INPUT_STYLE_VALID;
                     if (!meta::range_match(meta, v))
