@@ -264,7 +264,7 @@ namespace lsp
                 return false;
 
             float v;
-            status_t res = meta::parse_value(&v, value->get_utf8(), meta);
+            status_t res = meta::parse_value(&v, value->get_utf8(), meta, false);
             if (res != STATUS_OK)
                 return res;
 
@@ -355,7 +355,7 @@ namespace lsp
             if (popup->sValue.text()->format(&value) == STATUS_OK)
             {
                 float v;
-                if (meta::parse_value(&v, value.get_utf8(), meta) == STATUS_OK)
+                if (meta::parse_value(&v, value.get_utf8(), meta, false) == STATUS_OK)
                 {
                     style = INPUT_STYLE_VALID;
                     if (!meta::range_match(meta, v))
@@ -491,7 +491,7 @@ namespace lsp
 
             // Set-up value
             char buf[TMP_BUF_SIZE];
-            format_value(buf, TMP_BUF_SIZE, mdata, _this->nNote, _this->nDigits);
+            format_value(buf, TMP_BUF_SIZE, mdata, _this->nNote, _this->nDigits, false);
             popup->sValue.text()->set_raw(buf);
             popup->sValue.selection()->set_all();
 
