@@ -25,7 +25,7 @@
 
 #define LSP_PLUGINS_GRAPH_EQUALIZER_VERSION_MAJOR       1
 #define LSP_PLUGINS_GRAPH_EQUALIZER_VERSION_MINOR       0
-#define LSP_PLUGINS_GRAPH_EQUALIZER_VERSION_MICRO       8
+#define LSP_PLUGINS_GRAPH_EQUALIZER_VERSION_MICRO       11
 
 #define LSP_PLUGINS_GRAPH_EQUALIZER_VERSION  \
     LSP_MODULE_VERSION( \
@@ -40,7 +40,9 @@ namespace lsp
     {
         //-------------------------------------------------------------------------
         // Graphic Equalizer
-        static const int graph_equalizer_classes[] = { C_MULTI_EQ, -1 };
+        static const int plugin_classes[]           = { C_MULTI_EQ, -1 };
+        static const int clap_features_mono[]       = { CF_AUDIO_EFFECT, CF_EQUALIZER, CF_MONO, -1 };
+        static const int clap_features_stereo[]     = { CF_AUDIO_EFFECT, CF_EQUALIZER, CF_STEREO, -1 };
 
         static const port_item_t band_fft_mode[] =
         {
@@ -341,8 +343,10 @@ namespace lsp
             "rvwk",
             LSP_LADSPA_GRAPH_EQUALIZER_BASE + 0,
             LSP_LADSPA_URI("graph_equalizer_x16_mono"),
+            LSP_CLAP_URI("graph_equalizer_x16_mono"),
             LSP_PLUGINS_GRAPH_EQUALIZER_VERSION,
-            graph_equalizer_classes,
+            plugin_classes,
+            clap_features_mono,
             E_INLINE_DISPLAY | E_DUMP_STATE,
             graph_equalizer_x16_mono_ports,
             "equalizer/graphic/mono.xml",
@@ -363,8 +367,10 @@ namespace lsp
             "vnca",
             LSP_LADSPA_GRAPH_EQUALIZER_BASE + 1,
             LSP_LADSPA_URI("graph_equalizer_x32_mono"),
+            LSP_CLAP_URI("graph_equalizer_x32_mono"),
             LSP_PLUGINS_GRAPH_EQUALIZER_VERSION,
-            graph_equalizer_classes,
+            plugin_classes,
+            clap_features_mono,
             E_INLINE_DISPLAY | E_DUMP_STATE,
             graph_equalizer_x32_mono_ports,
             "equalizer/graphic/mono.xml",
@@ -385,8 +391,10 @@ namespace lsp
             "argl",
             LSP_LADSPA_GRAPH_EQUALIZER_BASE + 2,
             LSP_LADSPA_URI("graph_equalizer_x16_stereo"),
+            LSP_CLAP_URI("graph_equalizer_x16_stereo"),
             LSP_PLUGINS_GRAPH_EQUALIZER_VERSION,
-            graph_equalizer_classes,
+            plugin_classes,
+            clap_features_stereo,
             E_INLINE_DISPLAY | E_DUMP_STATE,
             graph_equalizer_x16_stereo_ports,
             "equalizer/graphic/stereo.xml",
@@ -407,8 +415,10 @@ namespace lsp
             "nvsd",
             LSP_LADSPA_GRAPH_EQUALIZER_BASE + 3,
             LSP_LADSPA_URI("graph_equalizer_x32_stereo"),
+            LSP_CLAP_URI("graph_equalizer_x32_stereo"),
             LSP_PLUGINS_GRAPH_EQUALIZER_VERSION,
-            graph_equalizer_classes,
+            plugin_classes,
+            clap_features_stereo,
             E_INLINE_DISPLAY | E_DUMP_STATE,
             graph_equalizer_x32_stereo_ports,
             "equalizer/graphic/stereo.xml",
@@ -429,8 +439,10 @@ namespace lsp
             "zefi",
             LSP_LADSPA_GRAPH_EQUALIZER_BASE + 4,
             LSP_LADSPA_URI("graph_equalizer_x16_lr"),
+            LSP_CLAP_URI("graph_equalizer_x16_lr"),
             LSP_PLUGINS_GRAPH_EQUALIZER_VERSION,
-            graph_equalizer_classes,
+            plugin_classes,
+            clap_features_stereo,
             E_INLINE_DISPLAY | E_DUMP_STATE,
             graph_equalizer_x16_lr_ports,
             "equalizer/graphic/lr.xml",
@@ -451,8 +463,10 @@ namespace lsp
             "0heu",
             LSP_LADSPA_GRAPH_EQUALIZER_BASE + 5,
             LSP_LADSPA_URI("graph_equalizer_x32_lr"),
+            LSP_CLAP_URI("graph_equalizer_x32_lr"),
             LSP_PLUGINS_GRAPH_EQUALIZER_VERSION,
-            graph_equalizer_classes,
+            plugin_classes,
+            clap_features_stereo,
             E_INLINE_DISPLAY | E_DUMP_STATE,
             graph_equalizer_x32_lr_ports,
             "equalizer/graphic/lr.xml",
@@ -473,8 +487,10 @@ namespace lsp
             "woys",
             LSP_LADSPA_GRAPH_EQUALIZER_BASE + 6,
             LSP_LADSPA_URI("graph_equalizer_x16_ms"),
+            LSP_CLAP_URI("graph_equalizer_x16_ms"),
             LSP_PLUGINS_GRAPH_EQUALIZER_VERSION,
-            graph_equalizer_classes,
+            plugin_classes,
+            clap_features_stereo,
             E_INLINE_DISPLAY | E_DUMP_STATE,
             graph_equalizer_x16_ms_ports,
             "equalizer/graphic/ms.xml",
@@ -495,8 +511,10 @@ namespace lsp
             "ku8j",
             LSP_LADSPA_GRAPH_EQUALIZER_BASE + 7,
             LSP_LADSPA_URI("graph_equalizer_x32_ms"),
+            LSP_CLAP_URI("graph_equalizer_x32_ms"),
             LSP_PLUGINS_GRAPH_EQUALIZER_VERSION,
-            graph_equalizer_classes,
+            plugin_classes,
+            clap_features_stereo,
             E_INLINE_DISPLAY | E_DUMP_STATE,
             graph_equalizer_x32_ms_ports,
             "equalizer/graphic/ms.xml",
