@@ -136,6 +136,8 @@
 			<li><b>Side</b> - side part of signal is used for sidechain processing.</li>
 			<li><b>Left</b> - only left channel is used for sidechain processing.</li>
 			<li><b>Right</b> - only right channel is used for sidechain processing.</li>
+			<li><b>Min</b> - the absolute minimum value is taken from stereo input.</li>
+			<li><b>Max</b> - the absolute maximum value is taken from stereo input.</li>
 		<?php } ?>
 	</ul>
 	<li><b>Sidechain Lookahead</b> - look-ahead time of the sidechain relative to the input signal.</li>
