@@ -35,38 +35,38 @@ namespace lsp
     {
         struct para_equalizer_metadata
         {
-            static const float          FREQ_MIN            = SPEC_FREQ_MIN;
-            static const float          FREQ_MAX            = SPEC_FREQ_MAX;
-            static const float          FREQ_DFL            = 1000;
-            static const float          FREQ_STEP           = 0.002;
+            static constexpr float          FREQ_MIN            = SPEC_FREQ_MIN;
+            static constexpr float          FREQ_MAX            = SPEC_FREQ_MAX;
+            static constexpr float          FREQ_DFL            = 1000;
+            static constexpr float          FREQ_STEP           = 0.002;
 
-            static const size_t         FFT_RANK            = 13;
-            static const size_t         FFT_ITEMS           = 1 << FFT_RANK;
-            static const size_t         MESH_POINTS         = 640;
-            static const size_t         FILTER_MESH_POINTS  = MESH_POINTS + 2;
-            static const size_t         FFT_WINDOW          = lsp::dspu::windows::HANN;
-            static const size_t         FFT_ENVELOPE        = lsp::dspu::envelope::PINK_NOISE;
+            static constexpr size_t         FFT_RANK            = 13;
+            static constexpr size_t         FFT_ITEMS           = 1 << FFT_RANK;
+            static constexpr size_t         MESH_POINTS         = 640;
+            static constexpr size_t         FILTER_MESH_POINTS  = MESH_POINTS + 2;
+            static constexpr size_t         FFT_WINDOW          = lsp::dspu::windows::HANN;
+            static constexpr size_t         FFT_ENVELOPE        = lsp::dspu::envelope::PINK_NOISE;
 
-            static const float          REACT_TIME_MIN      = 0.000;
-            static const float          REACT_TIME_MAX      = 1.000;
-            static const float          REACT_TIME_DFL      = 0.200;
-            static const float          REACT_TIME_STEP     = 0.001;
+            static constexpr float          REACT_TIME_MIN      = 0.000;
+            static constexpr float          REACT_TIME_MAX      = 1.000;
+            static constexpr float          REACT_TIME_DFL      = 0.200;
+            static constexpr float          REACT_TIME_STEP     = 0.001;
 
-            static const float          ZOOM_MIN            = GAIN_AMP_M_36_DB;
-            static const float          ZOOM_MAX            = GAIN_AMP_0_DB;
-            static const float          ZOOM_DFL            = GAIN_AMP_0_DB;
-            static const float          ZOOM_STEP           = 0.025f;
+            static constexpr float          ZOOM_MIN            = GAIN_AMP_M_36_DB;
+            static constexpr float          ZOOM_MAX            = GAIN_AMP_0_DB;
+            static constexpr float          ZOOM_DFL            = GAIN_AMP_0_DB;
+            static constexpr float          ZOOM_STEP           = 0.025f;
 
-            static const float          IN_GAIN_DFL         = 1.0f;
-            static const float          OUT_GAIN_DFL        = 1.0f;
-            static const size_t         MODE_DFL            = 0;
+            static constexpr float          IN_GAIN_DFL         = 1.0f;
+            static constexpr float          OUT_GAIN_DFL        = 1.0f;
+            static constexpr size_t         MODE_DFL            = 0;
 
-            static const float          PITCH_MIN           = -120.0f;
-            static const float          PITCH_MAX           = 120.0f;
-            static const float          PITCH_DFL           = 0.0f;
-            static const float          PITCH_STEP          = 0.01f;
+            static constexpr float          PITCH_MIN           = -120.0f;
+            static constexpr float          PITCH_MAX           = 120.0f;
+            static constexpr float          PITCH_DFL           = 0.0f;
+            static constexpr float          PITCH_STEP          = 0.01f;
 
-            static const size_t         REFRESH_RATE        = 20;
+            static constexpr size_t         REFRESH_RATE        = 20;
 
             enum eq_filter_t
             {
