@@ -19,6 +19,7 @@
  * along with lsp-plugins-para-equalizer. If not, see <https://www.gnu.org/licenses/>.
  */
 
+#include <lsp-plug.in/dsp-units/units.h>
 #include <lsp-plug.in/fmt/RoomEQWizard.h>
 #include <lsp-plug.in/stdlib/string.h>
 
@@ -73,16 +74,26 @@ namespace lsp
 
         para_equalizer_ui::para_equalizer_ui(const meta::plugin_t *meta): ui::Module(meta)
         {
-            pRewImport  = NULL;
-            pRewPath    = NULL;
-            fmtStrings  = fmt_strings;
+            pRewPath        = NULL;
+            pRewImport      = NULL;
+            pGraph          = NULL;
+            fmtStrings      = fmt_strings;
+            nSplitChannels  = 1;
+            nXAxisIndex     = -1;
+            nYAxisIndex     = -1;
 
-            if ((!strcmp(meta->lv2_uri, meta::para_equalizer_x16_lr.lv2_uri)) ||
-                (!strcmp(meta->lv2_uri, meta::para_equalizer_x32_lr.lv2_uri)))
+            if ((!strcmp(meta->uid, meta::para_equalizer_x16_lr.uid)) ||
+                (!strcmp(meta->uid, meta::para_equalizer_x32_lr.uid)))
+            {
                 fmtStrings      = fmt_strings_lr;
-            else if ((!strcmp(meta->lv2_uri, meta::para_equalizer_x16_ms.lv2_uri)) ||
-                     (!strcmp(meta->lv2_uri, meta::para_equalizer_x32_ms.lv2_uri)))
+                nSplitChannels  = 2;
+            }
+            else if ((!strcmp(meta->uid, meta::para_equalizer_x16_ms.uid)) ||
+                 (!strcmp(meta->uid, meta::para_equalizer_x32_ms.uid)))
+            {
                 fmtStrings      = fmt_strings_ms;
+                nSplitChannels  = 2;
+            }
         }
 
         para_equalizer_ui::~para_equalizer_ui()
@@ -186,6 +197,18 @@ namespace lsp
             return STATUS_OK;
         }
 
+        status_t para_equalizer_ui::slot_graph_dbl_click(tk::Widget *sender, void *ptr, void *data)
+        {
+            para_equalizer_ui *_this = static_cast<para_equalizer_ui *>(ptr);
+            if (_this == NULL)
+                return STATUS_BAD_STATE;
+
+            ws::event_t *ev = static_cast<ws::event_t *>(data);
+            _this->on_graph_dbl_click(ev->nLeft, ev->nTop);
+
+            return STATUS_OK;
+        }
+
         status_t para_equalizer_ui::post_init()
         {
             status_t res = ui::Module::post_init();
@@ -211,15 +234,117 @@ namespace lsp
                 menu->add(child);
             }
 
+            // Bind double-click handler
+            pGraph              = tk::widget_cast<tk::Graph>(wnd->widgets()->find("para_eq_graph"));
+            if (pGraph != NULL)
+            {
+                pGraph->slots()->bind(tk::SLOT_MOUSE_DBL_CLICK, slot_graph_dbl_click, this);
+                nXAxisIndex         = find_axis("para_eq_ox");
+                nYAxisIndex         = find_axis("para_eq_oy");
+            }
+
             return STATUS_OK;
         }
 
-        void para_equalizer_ui::set_port_value(const char *base, size_t id, float value)
+        void para_equalizer_ui::on_graph_dbl_click(ssize_t x, ssize_t y)
+        {
+            if ((pGraph == NULL) || (nXAxisIndex < 0) || (nYAxisIndex < 0))
+                return;
+
+            float freq = 0.0f, gain = 0.0f;
+            if (pGraph->xy_to_axis(nXAxisIndex, &freq, x, y) != STATUS_OK)
+                return;
+            if (pGraph->xy_to_axis(nYAxisIndex, &gain, x, y) != STATUS_OK)
+                return;
+
+            lsp_trace("Double click: x=%d, y=%d, freq=%.2f, gain=%.4f (%.2f db)",
+                x, y, freq, gain, dspu::gain_to_db(gain));
+
+            // Obtain which port set (left/right/mid/side) should be updated
+            ui::IPort *selector = pWrapper->port("fsel");
+            ssize_t channel     = (selector != NULL) ? size_t(selector->value()) % nSplitChannels : 0;
+            if (channel < 0)
+            {
+                lsp_trace("Could not allocate channel");
+                return;
+            }
+
+            // Allocate new port index
+            ssize_t fid         = -1;
+            for (size_t i=0; i<32; ++i)
+            {
+                ssize_t type = get_filter_type(i, channel);
+                if (type == meta::para_equalizer_metadata::EQF_OFF)
+                {
+                    fid             = i;
+                    break;
+                }
+                else if (type < 0)
+                    break;
+            }
+
+            if (fid < 0)
+            {
+                lsp_trace("Could not allocate new equalizer band");
+                return;
+            }
+
+            // Equalizer band has been allocated, do the stuff
+            size_t mask         = 1 << channel;
+
+            // Set-up parameters
+            size_t filter_type =
+                (freq <= 100.0f)    ? meta::para_equalizer_metadata::EQF_HIPASS     :
+                (freq <= 300.0f)    ? meta::para_equalizer_metadata::EQF_LOSHELF    :
+                (freq <= 7000.0f)   ? meta::para_equalizer_metadata::EQF_BELL       :
+                (freq <= 15000.0f)  ? meta::para_equalizer_metadata::EQF_HISHELF    :
+                                      meta::para_equalizer_metadata::EQF_LOPASS;
+
+            float filter_quality = (filter_type == meta::para_equalizer_metadata::EQF_BELL) ? 2.0f : 0.5f;
+
+            // Set-up filter type
+            set_filter_mode(fid, mask, meta::para_equalizer_metadata::EFM_RLC_BT);
+            set_filter_type(fid, mask, filter_type);
+            set_filter_frequency(fid, mask, freq);
+            set_filter_slope(fid, mask, 1);
+            set_filter_gain(fid, mask, gain);
+            set_filter_quality(fid, mask, filter_quality);
+            set_filter_enabled(fid, mask, true);
+            set_filter_solo(fid, mask, false);
+        }
+
+        ssize_t para_equalizer_ui::find_axis(const char *id)
+        {
+            if (pGraph == NULL)
+                return -1;
+
+            ctl::Window *wnd    = pWrapper->controller();
+            tk::GraphAxis *axis = tk::widget_cast<tk::GraphAxis>(wnd->widgets()->find(id));
+            if (axis == NULL)
+                return -1;
+
+            for (size_t i=0; ; ++i)
+            {
+                tk::GraphAxis *ax = pGraph->axis(i);
+                if (ax == NULL)
+                    break;
+                else if (ax == axis)
+                    return i;
+            }
+
+            return -1;
+        }
+
+        void para_equalizer_ui::set_port_value(const char *base, size_t mask, size_t id, float value)
         {
             char port_id[32];
+            size_t pattern = 1 << 0;
 
-            for (const char **fmt = fmtStrings; *fmt != NULL; ++fmt)
+            for (const char **fmt = fmtStrings; *fmt != NULL; ++fmt, pattern <<= 1)
             {
+                if (!(mask & pattern))
+                    continue;
+
                 ::snprintf(port_id, sizeof(port_id)/sizeof(char), *fmt, base, int(id));
                 ui::IPort *p = pWrapper->port(port_id);
                 if (p != NULL)
@@ -230,45 +355,65 @@ namespace lsp
             }
         }
 
-        void para_equalizer_ui::set_filter_mode(size_t id, size_t value)
+        void para_equalizer_ui::set_filter_mode(size_t id, size_t mask, size_t value)
         {
-            set_port_value("fm", id, value);
+            set_port_value("fm", mask, id, value);
         }
 
-        void para_equalizer_ui::set_filter_type(size_t id, size_t value)
+        void para_equalizer_ui::set_filter_type(size_t id, size_t mask, size_t value)
         {
-            set_port_value("ft", id, value);
+            set_port_value("ft", mask, id, value);
         }
 
-        void para_equalizer_ui::set_filter_frequency(size_t id, double value)
+        ssize_t para_equalizer_ui::get_filter_type(size_t id, size_t channel)
         {
-            set_port_value("f", id, value);
+            char port_id[32];
+            size_t index = 0;
+
+            for (const char **fmt = fmtStrings; *fmt != NULL; ++fmt, ++index)
+            {
+                if (index != channel)
+                    continue;
+
+                ::snprintf(port_id, sizeof(port_id)/sizeof(char), *fmt, "ft", int(id));
+                ui::IPort *p = pWrapper->port(port_id);
+                if (p == NULL)
+                    return -STATUS_NOT_FOUND;
+
+                return ssize_t(p->value());
+            }
+
+            return -STATUS_NOT_FOUND;
         }
 
-        void para_equalizer_ui::set_filter_quality(size_t id, double value)
+        void para_equalizer_ui::set_filter_frequency(size_t id, size_t mask, float value)
         {
-            set_port_value("q", id, value);
+            set_port_value("f", mask, id, value);
         }
 
-        void para_equalizer_ui::set_filter_gain(size_t id, double value)
+        void para_equalizer_ui::set_filter_quality(size_t id, size_t mask, float value)
         {
-            double gain = expf(0.05 * value * M_LN10);
-            set_port_value("g", id, gain);
+            set_port_value("q", mask, id, value);
         }
 
-        void para_equalizer_ui::set_filter_slope(size_t id, size_t slope)
+        void para_equalizer_ui::set_filter_gain(size_t id, size_t mask, float value)
         {
-            set_port_value("s", id, slope - 1);
+            set_port_value("g", mask, id, value);
         }
 
-        void para_equalizer_ui::set_filter_enabled(size_t id, bool enabled)
+        void para_equalizer_ui::set_filter_slope(size_t id, size_t mask, size_t slope)
         {
-            set_port_value("xm", id, (enabled) ? 0.0f : 1.0f);
+            set_port_value("s", mask, id, slope - 1);
         }
 
-        void para_equalizer_ui::set_filter_solo(size_t id, bool solo)
+        void para_equalizer_ui::set_filter_enabled(size_t id, size_t mask, bool enabled)
         {
-            set_port_value("xs", id, (solo) ? 1.0f : 0.0f);
+            set_port_value("xm", mask, id, (enabled) ? 0.0f : 1.0f);
+        }
+
+        void para_equalizer_ui::set_filter_solo(size_t id, size_t mask, bool solo)
+        {
+            set_port_value("xs", mask, id, (solo) ? 1.0f : 0.0f);
         }
 
         status_t para_equalizer_ui::import_rew_file(const LSPString *path)
@@ -361,14 +506,14 @@ namespace lsp
                     continue;
 
                 // Set-up parameters
-                set_filter_mode(fid, mode);
-                set_filter_type(fid, type);
-                set_filter_slope(fid, 1);
-                set_filter_frequency(fid, freq);
-                set_filter_gain(fid, gain);
-                set_filter_quality(fid, quality);
-                set_filter_enabled(fid, f->enabled);
-                set_filter_solo(fid, false);
+                set_filter_mode(fid, 0x03, mode);
+                set_filter_type(fid, 0x03, type);
+                set_filter_slope(fid, 0x03, 1);
+                set_filter_frequency(fid, 0x03, freq);
+                set_filter_gain(fid, 0x03, dspu::db_to_gain(gain));
+                set_filter_quality(fid, 0x03, quality);
+                set_filter_enabled(fid, 0x03, f->enabled);
+                set_filter_solo(fid, 0x03, false);
 
                 // Increment imported filter number
                 ++fid;
@@ -377,12 +522,12 @@ namespace lsp
             // Reset state of all other filters
             for (; fid < 32; ++fid)
             {
-                set_filter_type(fid, meta::para_equalizer_metadata::EQF_OFF);
-                set_filter_slope(fid, 1);
-                set_filter_gain(fid, 1.0f);
-                set_filter_quality(fid, 0.0f);
-                set_filter_enabled(fid, true);
-                set_filter_solo(fid, false);
+                set_filter_type(fid, 0x03, meta::para_equalizer_metadata::EQF_OFF);
+                set_filter_slope(fid, 0x03, 1);
+                set_filter_gain(fid, 0x03, 1.0f);
+                set_filter_quality(fid, 0x03, 0.0f);
+                set_filter_enabled(fid, 0x03, true);
+                set_filter_solo(fid, 0x03, false);
             }
 
             return STATUS_OK;
