@@ -24,19 +24,14 @@
 
 #define LSP_R3D_GLX_LIB_MAJOR           1
 #define LSP_R3D_GLX_LIB_MINOR           0
-#define LSP_R3D_GLX_LIB_MICRO           2
+#define LSP_R3D_GLX_LIB_MICRO           8
 
-#ifdef LSP_R3D_GLX_LIB_BUILTIN
-    #define LSP_R3D_GLX_LIB_EXPORT
-    #define LSP_R3D_GLX_LIB_CEXPORT
-    #define LSP_R3D_GLX_LIB_IMPORT          LSP_SYMBOL_IMPORT
-    #define LSP_R3D_GLX_LIB_CIMPORT         LSP_CSYMBOL_IMPORT
+#if defined(LSP_R3D_GLX_LIB_PUBLISHER)
+    #define LSP_R3D_GLX_LIB_PUBLIC          LSP_EXPORT_MODIFIER
+#elif defined(LSP_R3D_GLX_LIB_BUILTIN) || defined(LSP_IDE_DEBUG)
+    #define LSP_R3D_GLX_LIB_PUBLIC
 #else
-    #define LSP_R3D_GLX_LIB_EXPORT          LSP_SYMBOL_EXPORT
-    #define LSP_R3D_GLX_LIB_CEXPORT         LSP_CSYMBOL_EXPORT
-    #define LSP_R3D_GLX_LIB_IMPORT          LSP_SYMBOL_IMPORT
-    #define LSP_R3D_GLX_LIB_CIMPORT         LSP_CSYMBOL_IMPORT
+    #define LSP_R3D_GLX_LIB_PUBLIC          LSP_IMPORT_MODIFIER
 #endif
 
-
 #endif /* LSP_PLUG_IN_GLX_VERSION_H_ */
