@@ -304,6 +304,10 @@ namespace lsp
                 status_t        get_noext(LSPString *path) const;
                 status_t        get_noext(Path *path) const;
 
+                status_t        get_last_noext(char *path, size_t maxlen) const;
+                status_t        get_last_noext(LSPString *path) const;
+                status_t        get_last_noext(Path *path) const;
+
                 status_t        get_parent(char *path, size_t maxlen) const;
                 status_t        get_parent(LSPString *path) const;
                 status_t        get_parent(Path *path) const;
