@@ -86,6 +86,14 @@ namespace lsp
              */
             inline size_t length() const { return nLength; }
 
+            /**
+             * Get the length of the range
+             * @param first the index of first character
+             * @param last the index of last character
+             * @return final length of the range
+             */
+            size_t range_length(ssize_t first, ssize_t last) const;
+
             /**
              * Set the length of the string, allows only to cut data from tail
              * @param length the length of the string
@@ -214,8 +222,8 @@ namespace lsp
             bool append(const LSPString *src);
             bool append(const LSPString *src, ssize_t first);
             bool append(const LSPString *src, ssize_t first, ssize_t last);
-            inline bool append_ascii(const char *arr) { return append_ascii(arr, ::strlen(arr)); };
-            inline bool append_utf8(const char *arr) { return append_utf8(arr, ::strlen(arr)); };
+            inline bool append_ascii(const char *arr) { return append_ascii(arr, ::strlen(arr));    };
+            inline bool append_utf8(const char *arr)  { return append_utf8(arr, ::strlen(arr));     };
             bool append_utf16(const lsp_utf16_t *arr);
 
             bool prepend(lsp_wchar_t ch);
@@ -225,8 +233,8 @@ namespace lsp
             bool prepend(const LSPString *src);
             bool prepend(const LSPString *src, ssize_t first);
             bool prepend(const LSPString *src, ssize_t first, ssize_t last);
-            inline bool prepend_ascii(const char *arr) { return prepend_ascii(arr, ::strlen(arr)); };
-            inline bool prepend_utf8(const char *arr) { return prepend_ascii(arr, ::strlen(arr)); };
+            inline bool prepend_ascii(const char *arr) { return prepend_ascii(arr, ::strlen(arr));  };
+            inline bool prepend_utf8(const char *arr)  { return prepend_utf8(arr, ::strlen(arr));   };
 
             /** Get unicode character at the specified position
              *
@@ -283,6 +291,12 @@ namespace lsp
             bool set_utf16(const lsp_utf16_t *s, size_t n);
             bool set_utf16(const lsp_utf16_t *s);
 
+            bool set_utf16le(const lsp_utf16_t *s, size_t n);
+            bool set_utf16le(const lsp_utf16_t *s);
+
+            bool set_utf16be(const lsp_utf16_t *s, size_t n);
+            bool set_utf16be(const lsp_utf16_t *s);
+
             bool set_ascii(const char *s, size_t n);
             inline bool set_ascii(const char *s) { return set_ascii(s, ::strlen(s)); };
 
@@ -296,7 +310,15 @@ namespace lsp
 
             const lsp_utf16_t *get_utf16(ssize_t first, ssize_t last) const;
             inline const lsp_utf16_t *get_utf16(ssize_t first) const { return get_utf16(first, nLength); };
-            const lsp_utf16_t *get_utf16() const { return get_utf16(0, nLength); };
+            inline const lsp_utf16_t *get_utf16() const { return get_utf16(0, nLength); };
+
+            const lsp_utf16_t *get_utf16le(ssize_t first, ssize_t last) const;
+            inline const lsp_utf16_t *get_utf16le(ssize_t first) const { return get_utf16le(first, nLength); };
+            inline const lsp_utf16_t *get_utf16le() const { return get_utf16le(0, nLength); };
+
+            const lsp_utf16_t *get_utf16be(ssize_t first, ssize_t last) const;
+            inline const lsp_utf16_t *get_utf16be(ssize_t first) const { return get_utf16be(first, nLength); };
+            inline const lsp_utf16_t *get_utf16be() const { return get_utf16be(0, nLength); };
 
             const char *get_ascii(ssize_t first, ssize_t last) const;
             inline const char *get_ascii(ssize_t first) const { return get_ascii(first, nLength); };
@@ -337,6 +359,19 @@ namespace lsp
             inline lsp_utf16_t *clone_utf16(ssize_t first) const { return clone_utf16(NULL, first, nLength); };
             inline lsp_utf16_t *clone_utf16() const { return clone_utf16(NULL, 0, nLength); };
 
+            lsp_utf16_t *clone_utf16le(size_t *bytes, ssize_t first, ssize_t last) const;
+            inline lsp_utf16_t *clone_utf16le(size_t *bytes, ssize_t first) const { return clone_utf16le(bytes, first, nLength); };
+            inline lsp_utf16_t *clone_utf16le(size_t *bytes) const { return clone_utf16le(bytes, 0, nLength); };
+            inline lsp_utf16_t *clone_utf16le(ssize_t first, ssize_t last) const { return clone_utf16le(NULL, first, last); };
+            inline lsp_utf16_t *clone_utf16le(ssize_t first) const { return clone_utf16le(NULL, first, nLength); };
+            inline lsp_utf16_t *clone_utf16le() const { return clone_utf16le(NULL, 0, nLength); };
+
+            lsp_utf16_t *clone_utf16be(size_t *bytes, ssize_t first, ssize_t last) const;
+            inline lsp_utf16_t *clone_utf16be(size_t *bytes, ssize_t first) const { return clone_utf16be(bytes, first, nLength); };
+            inline lsp_utf16_t *clone_utf16be(size_t *bytes) const { return clone_utf16be(bytes, 0, nLength); };
+            inline lsp_utf16_t *clone_utf16be(ssize_t first, ssize_t last) const { return clone_utf16be(NULL, first, last); };
+            inline lsp_utf16_t *clone_utf16be(ssize_t first) const { return clone_utf16be(NULL, first, nLength); };
+            inline lsp_utf16_t *clone_utf16be() const { return clone_utf16be(NULL, 0, nLength); };
             /**
              * Clone string as set of UTF-16 characters. 1 ascii character at the tail will contain additional end-of-line.
              */
@@ -562,6 +597,13 @@ namespace lsp
              * @return hash code
              */
             size_t  hash() const;
+
+            /**
+             * Convert line endings
+             * @return true if the conversion has succeeded
+             */
+            bool to_dos();
+            bool to_unix();
     };
     
     // LLTL specialization for String class
