@@ -456,7 +456,7 @@ namespace lsp
             return (path != NULL) ? get_ext(&path->sPath) : STATUS_BAD_ARGUMENTS;
         }
 
-        status_t Path::get_noext(char *path, size_t maxlen) const
+        status_t Path::get_last_noext(char *path, size_t maxlen) const
         {
             if (path == NULL)
                 return STATUS_BAD_ARGUMENTS;
@@ -489,7 +489,7 @@ namespace lsp
             return STATUS_OK;
         }
 
-        status_t Path::get_noext(LSPString *path) const
+        status_t Path::get_last_noext(LSPString *path) const
         {
             if (path == NULL)
                 return STATUS_BAD_ARGUMENTS;
@@ -512,6 +512,67 @@ namespace lsp
             return (path->set(&sPath, start, end)) ? STATUS_OK : STATUS_NO_MEM;
         }
 
+        status_t Path::get_last_noext(Path *path) const
+        {
+            return (path != NULL) ? get_last_noext(&path->sPath) : STATUS_BAD_ARGUMENTS;
+        }
+
+        status_t Path::get_noext(char *path, size_t maxlen) const
+        {
+            if (path == NULL)
+                return STATUS_BAD_ARGUMENTS;
+
+            ssize_t start, next, end;
+
+            start   = sPath.rindex_of(FILE_SEPARATOR_C);
+            start   = (start < 0) ? 0 : start + 1;
+
+            // Lookup for last dot
+            end     = sPath.index_of(start, '.');
+            if (end >= 0)
+            {
+                while ((next = sPath.index_of(end + 1, '.')) >= 0)
+                    end     = next;
+            }
+            if (end < 0)
+                end = sPath.length();
+
+            // Copy data to output
+            const char *utf8 = sPath.get_utf8(0, end);
+            if (utf8 == NULL)
+                return STATUS_NO_MEM;
+
+            size_t len = ::strlen(utf8);
+            if (len >= maxlen)
+                return STATUS_TOO_BIG;
+
+            ::memcpy(path, utf8, len + 1);
+            return STATUS_OK;
+        }
+
+        status_t Path::get_noext(LSPString *path) const
+        {
+            if (path == NULL)
+                return STATUS_BAD_ARGUMENTS;
+
+            ssize_t start, next, end;
+
+            start   = sPath.rindex_of(FILE_SEPARATOR_C);
+            start   = (start < 0) ? 0 : start + 1;
+
+            // Lookup for last dot
+            end     = sPath.index_of(start, '.');
+            if (end >= 0)
+            {
+                while ((next = sPath.index_of(end + 1, '.')) >= 0)
+                    end     = next;
+            }
+            if (end < 0)
+                end = sPath.length();
+
+            return (path->set(&sPath, 0, end)) ? STATUS_OK : STATUS_NO_MEM;
+        }
+
         status_t Path::get_noext(Path *path) const
         {
             return (path != NULL) ? get_noext(&path->sPath) : STATUS_BAD_ARGUMENTS;
