@@ -309,6 +309,10 @@ namespace lsp
             handle_t *h     = static_cast<handle_t *>(malloc(sizeof(handle_t)));
             if (h == NULL)
                 return set_error(STATUS_NO_MEM);
+            h->pMMIO        = NULL;
+            h->pACM         = NULL;
+            h->pFormat      = NULL;
+            h->nTotalFrames = 0;
             lsp_finally { close_handle(h);  };
 
             // Create MMIO
