@@ -95,6 +95,7 @@ namespace lsp
             nCurrIndex      = -1;
             nLastIndex      = -1;
             nKeyScroll      = SCR_NONE;
+            pHoverItem      = NULL;
 
             sArea.nLeft     = 0;
             sArea.nTop      = 0;
@@ -450,6 +451,20 @@ namespace lsp
             realize_children();
 
             // Update scrolling
+//            item_t *curr    = find_by_index(nCurrIndex);
+//            ssize_t start   = vVisible.index_of(curr);
+//            if (start >= 0)
+//            {
+//                if (scroll_to_item(start))
+//                    realize_children();
+//            }
+
+            // Call parent for realize
+            WidgetContainer::realize(r);
+        }
+
+        void ListBox::scroll_to_current()
+        {
             item_t *curr    = find_by_index(nCurrIndex);
             ssize_t start   = vVisible.index_of(curr);
             if (start >= 0)
@@ -457,9 +472,6 @@ namespace lsp
                 if (scroll_to_item(start))
                     realize_children();
             }
-
-            // Call parent for realize
-            WidgetContainer::realize(r);
         }
 
         void ListBox::realize_children()
@@ -545,9 +557,9 @@ namespace lsp
                     if (force)
                     {
                         s->clip_begin(area);
-                        s->fill_rect(col, h.nLeft + h.nWidth, v.nTop + v.nHeight, v.nWidth, h.nHeight);
-                        s->fill_rect(col, v.nLeft - vsspacing, v.nTop, vsspacing, v.nHeight + hsspacing);
-                        s->fill_rect(col, h.nLeft, h.nTop - hsspacing, h.nWidth, hsspacing);
+                        s->fill_rect(col, SURFMASK_NONE, 0.0f, h.nLeft + h.nWidth, v.nTop + v.nHeight, v.nWidth, h.nHeight);
+                        s->fill_rect(col, SURFMASK_NONE, 0.0f, v.nLeft - vsspacing, v.nTop, vsspacing, v.nHeight + hsspacing);
+                        s->fill_rect(col, SURFMASK_NONE, 0.0f, h.nLeft, h.nTop - hsspacing, h.nWidth, hsspacing);
                         s->clip_end();
                     }
                 }
@@ -557,8 +569,8 @@ namespace lsp
                     if (force)
                     {
                         s->clip_begin(area);
-                        s->fill_rect(col, h.nLeft + h.nWidth, v.nTop + v.nHeight, v.nWidth, h.nHeight);
-                        s->fill_rect(col, h.nLeft, h.nTop - hsspacing, h.nWidth, hsspacing);
+                        s->fill_rect(col, SURFMASK_NONE, 0.0f, h.nLeft + h.nWidth, v.nTop + v.nHeight, v.nWidth, h.nHeight);
+                        s->fill_rect(col, SURFMASK_NONE, 0.0f, h.nLeft, h.nTop - hsspacing, h.nWidth, hsspacing);
                         s->clip_end();
                     }
                 }
@@ -577,7 +589,7 @@ namespace lsp
                 if (force)
                 {
                     s->clip_begin(area);
-                    s->fill_rect(col, v.nLeft - vsspacing, v.nTop, vsspacing, v.nHeight);
+                    s->fill_rect(col, SURFMASK_NONE, 0.0f, v.nLeft - vsspacing, v.nTop, vsspacing, v.nHeight);
                     s->clip_end();
                 }
             }
@@ -589,19 +601,19 @@ namespace lsp
                 {
                     // Draw the frame around
                     s->clip_begin(area);
-                        s->fill_frame(col, &sArea, &sList);
+                        s->fill_frame(col, SURFMASK_NONE, 0.0f, &sArea, &sList);
 
                         aa = s->set_antialiasing(true);
                             col.copy(sBorderColor);
                             xr = sArea;
-                            s->fill_round_rect(col, SURFMASK_ALL_CORNER, radius, &xr);
+                            s->fill_rect(col, SURFMASK_ALL_CORNER, radius, &xr);
 
                             col.copy(sListBgColor);
                             xr.nLeft       += border;
                             xr.nTop        += border;
                             xr.nWidth      -= border * 2;
                             xr.nHeight     -= border * 2;
-                            s->fill_round_rect(col, SURFMASK_ALL_CORNER, radius, &xr);
+                            s->fill_rect(col, SURFMASK_ALL_CORNER, radius, &xr);
 
                         s->set_antialiasing(aa);
                     s->clip_end();
@@ -638,21 +650,27 @@ namespace lsp
                         if (selected)
                         {
                             col.copy(li->bg_selected_color()->color());
-                            s->fill_rect(col, &it->r);
+                            s->fill_rect(col, SURFMASK_NONE, 0.0f, &it->r);
                             col.copy(li->text_selected_color()->color());
                         }
+                        else if (it->item == pHoverItem)
+                        {
+                            col.copy(li->bg_hover_color()->color());
+                            s->fill_rect(col, SURFMASK_NONE, 0.0f, &it->r);
+                            col.copy(li->text_hover_color()->color());
+                        }
                         else
                         {
                             li->get_actual_bg_color(col);
-                            s->fill_rect(col, &it->r);
+                            s->fill_rect(col, SURFMASK_NONE, 0.0f, &it->r);
                             col.copy(li->text_color()->color());
                         }
 
                         li->padding()->enter(&xr, &it->r, scaling);
                         sFont.draw(s, col,
-                                xr.nLeft,
-                                xr.nTop  + ((xr.nHeight - fp.Height) * 0.5f) + fp.Ascent,
-                                fscaling, &text);
+                            xr.nLeft,
+                            xr.nTop  + ((xr.nHeight - fp.Height) * 0.5f) + fp.Ascent,
+                            fscaling, &text);
                     }
                     s->clip_end();
                 }
@@ -717,6 +735,11 @@ namespace lsp
             if ((&_this->sHBar != sender) && (&_this->sVBar != sender))
                 return STATUS_OK;
 
+            if (&_this->sHBar == sender)
+                _this->sHScroll.commit_value(_this->sHBar.value()->get());
+            else if (&_this->sVBar == sender)
+                _this->sVScroll.commit_value(_this->sVBar.value()->get());
+
             _this->realize_children();
             _this->query_draw();
 
@@ -759,7 +782,11 @@ namespace lsp
             if (_this == NULL)
                 return;
 
-            item->set_parent(_this);
+            // Change parent only if we are working with the main item list.
+            if (_this->vItems.is(prop))
+            {
+                item->set_parent(_this);
+            }
             _this->query_resize();
         }
 
@@ -773,11 +800,15 @@ namespace lsp
             if (_this == NULL)
                 return;
 
-            // Remove widget from selection list
+            // Special logic if the message was originated by the item list
             if (_this->vItems.is(prop))
+            {
+                // Remove widget from selection list
                 _this->vSelected.remove(item);
+                // Unlink widget
+                _this->unlink_widget(item);
+            }
 
-            _this->unlink_widget(item);
             _this->query_resize();
         }
 
@@ -817,11 +848,8 @@ namespace lsp
 
         status_t ListBox::on_mouse_move(const ws::event_t *e)
         {
-            if (nBMask != ws::MCF_LEFT)
-                return STATUS_OK;
-
             item_t *it  = find_item(e->nLeft, e->nTop);
-            if (it != NULL)
+            if ((it != NULL) && (nBMask == ws::MCF_LEFT))
             {
                 nCurrIndex      = it->index;
                 if (e->nState & ws::MCF_SHIFT)
@@ -830,6 +858,23 @@ namespace lsp
                     select_single(nCurrIndex, e->nState & ws::MCF_CONTROL);
             }
 
+            ListBoxItem *hover_item = (it != NULL) ? it->item : NULL;
+            if (pHoverItem != hover_item)
+            {
+                pHoverItem  = hover_item;
+                query_draw();
+            }
+
+            return STATUS_OK;
+        }
+
+        status_t ListBox::on_mouse_out(const ws::event_t *e)
+        {
+            if (pHoverItem != NULL)
+            {
+                pHoverItem      = NULL;
+                query_draw();
+            }
             return STATUS_OK;
         }
 
